======================
Salt Table of Contents
======================

.. toctree::
    :maxdepth: 3
    :glob:

    topics/jobs/index
    topics/event/index
    topics/proxyminion/index
    topics/topology/index
    topics/highavailability/index
    topics/windows/index
    topics/cloud/index
    topics/netapi/index
    topics/virt/index
    topics/yaml/index
    glossary